Annotations

Struct Annotations 

pub struct Annotations {
    pub annotations2: Option<Vec<Annotation>>,
    /* private fields */
}
Annotations about the device’s state.

Clients typically upload the data straight to servers. So the data comes in the form of arbitrary key-value pairs that clients can directly forward to the servers.

Fields

annotations2: Option<Vec<Annotation>>

A vector of key-value string pairs. Keys are guaranteed to be unique.